ecosound.core package
=====================

Submodules
----------

ecosound.core.annotation module
-------------------------------

.. automodule:: ecosound.core.annotation
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.audiotools module
-------------------------------

.. automodule:: ecosound.core.audiotools
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.decorators module
-------------------------------

.. automodule:: ecosound.core.decorators
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.measurement module
--------------------------------

.. automodule:: ecosound.core.measurement
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.metadata module
-----------------------------

.. automodule:: ecosound.core.metadata
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.spectrogram module
--------------------------------

.. automodule:: ecosound.core.spectrogram
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.core.tools module
--------------------------

.. automodule:: ecosound.core.tools
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ecosound.core
   :members:
   :undoc-members:
   :show-inheritance:
